@@ -1,4 +1,6 @@
 from jinja2 import Environment, FileSystemLoader
+from importlib.resources import files
+import amautta_project
 import sys
 import os
 
@@ -9,8 +11,7 @@ def create():
         print("[INFO] No se encuentra en la carpeta del un microservicio.")
         sys.exit()
 
-    BASE_DIR = os.path.dirname(os.path.abspath(__file__))
-    TEMPLATE_DIR = os.path.join(BASE_DIR, 'templates')
+    TEMPLATE_DIR = str(files(amautta_project).joinpath("templates"))
     env = Environment(loader=FileSystemLoader(TEMPLATE_DIR))
 
     archivos = {
